import { Camera, CameraResultType, CameraSource, PermissionStatus } from '@capacitor/camera';

// Функция для запроса разрешений
async function requestCameraPermission() {
    const status = await Camera.requestPermissions();

    if (status.camera !== PermissionStatus.GRANTED) {
        console.error('Не удалось получить разрешение на использование камеры');
        alert('Разрешение на камеру не предоставлено. Пожалуйста, разрешите использование камеры.');
        return false;
    }
    return true;
}

export async function openCamera() {
    // Сначала проверяем разрешения
    const hasPermission = await requestCameraPermission();
    if (!hasPermission) {
        return; // Если разрешение не предоставлено, выходим
    }

    try {
        const image = await Camera.getPhoto({
            quality: 90,
            allowEditing: false,
            resultType: CameraResultType.Uri,
            source: CameraSource.Camera // Указывает, что нужно использовать камеру устройства
        });

        // Отображаем полученное изображение в теге <img>
        const imageUrl = image.webPath;
        const imgElement = document.getElementById('camera-image');
        imgElement.src = imageUrl;
        imgElement.style.display = 'block';  // Показываем картинку
    } catch (error) {
        console.error('Ошибка при доступе к камере:', error);
    }
}
